@@ -30,6 +30,7 @@ dataset_list = ['acled-conflict-data-for-libya', 'acled-conflict-data-for-liberi
 hxlupdate_list = [{'title': 'Quick Charts', 'resource_id': 'de6549d8-268b-4dfe-adaf-a4ae5c8510d5', 
                    'package_id': '6f36a41c-f126-4b18-aaaf-6c2ddfbc5d4d', 'view_type': 'hdx_hxl_preview', 
                    'description': '', 'id': '29cc5894-4306-4bef-96ce-b7a833e7986a'}]
+dataset_autocomplete = [{'match_field': 'name', 'match_displayed': 'acled-conflict-data-for-africa-1997-lastyear', 'name': 'acled-conflict-data-for-africa-1997-lastyear', 'title': 'ACLED Conflict Data for Africa 1997-2016'}]
 
 
 def mocksearch(url, datadict):
@@ -334,6 +335,23 @@ class TestDatasetCore:
 
         Configuration.read().remoteckan().session = MockSession()
 
+    @pytest.fixture(scope='function')
+    def post_autocomplete(self):
+        class MockSession(object):
+            @staticmethod
+            def post(url, data, headers, files, allow_redirects, auth=None):
+                decodedata = data.decode('utf-8')
+                datadict = json.loads(decodedata)
+                if 'autocomplete' not in url or 'acled' not in datadict['q']:
+                    return MockResponse(404,
+                                        '{"success": false, "error": {"message": "TEST ERROR: Not autocomplete", "__type": "TEST ERROR: Not Autocomplete Error"}, "help": "http://test-data.humdata.org/api/3/action/help_show?name=package_autocomplete"}')
+                result = json.dumps(dataset_autocomplete)
+                return MockResponse(200,
+                                    '{"success": true, "result": %s, "help": "http://test-data.humdata.org/api/3/action/help_show?name=package_autocomplete"}' % result)
+
+        Configuration.read().remoteckan().session = MockSession()
+
+
     def test_read_from_hdx(self, configuration, read):
         dataset = Dataset.read_from_hdx('TEST1')
         assert dataset['id'] == '6f36a41c-f126-4b18-aaaf-6c2ddfbc5d4d'
@@ -805,3 +823,6 @@ class TestDatasetCore:
         with pytest.raises(NotRequestableError):
             dataset.remove_filetype('csv')
         assert dataset.get_filetypes() == ['xlsx', 'csv', 'xls']
+
+    def test_autocomplete(self, configuration, post_autocomplete):
+        assert Dataset.autocomplete('acled') == dataset_autocomplete
