@@ -63,16 +63,16 @@ class TestKeywordArguments:
         assert testresult.actual_result == my_test_key
         UserAgent.clear_global()
         testresult.actual_result = None
-        my_test_hdxsite = 'test'
+        my_test_hdxsite = 'stage'
         facade(my_testfnkw, hdx_site=my_test_hdxsite, user_agent=my_user_agent, hdx_config_yaml=hdx_config_yaml,
                project_config_yaml=project_config_yaml, fn='site')
-        assert testresult.actual_result == 'https://%s-data.humdata.org' % my_test_hdxsite
+        assert testresult.actual_result == 'https://%s.data-humdata-org.ahconu.org' % my_test_hdxsite
         UserAgent.clear_global()
         testresult.actual_result = None
         monkeypatch.setenv('HDX_SITE', my_test_hdxsite)
         facade(my_testfnkw, hdx_site='feature', user_agent=my_user_agent, hdx_config_yaml=hdx_config_yaml,
                project_config_yaml=project_config_yaml, fn='site')
-        assert testresult.actual_result == 'https://%s-data.humdata.org' % my_test_hdxsite
+        assert testresult.actual_result == 'https://%s.data-humdata-org.ahconu.org' % my_test_hdxsite
         UserAgent.clear_global()
         my_test_hdxurl = 'http://other-data.humdata.org'
         monkeypatch.setenv('HDX_URL', my_test_hdxurl)
